@@ -3,11 +3,8 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Glorified metronome
 
-our $VERSION = '0.2002';
+our $VERSION = '0.2003';
 
-use Algorithm::Combinatorics qw(variations_with_repetition);
-use Math::Bezier;
-use MIDI::Util qw(dura_size);
 use Music::Duration;
 
 use Moo;
@@ -464,7 +461,7 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.2002
+version 0.2003
 
 =head1 SYNOPSIS
 
@@ -834,6 +831,10 @@ L<Algorithm::Combinatorics/variations_with_repetition>.
 
 This method accumulates beats in the object's B<counter> attribute.
 
+The B<vary> option is a hashref of coderefs, keyed by single character
+tokens, like the digits, 0-9.  The coderefs should add up to the
+B<duration> option.
+
 Defaults:
 
   instrument: snare
@@ -850,9 +851,13 @@ Defaults:
 
 =head1 SEE ALSO
 
-The metronome method sources in this module, the F<eg/*> programs in
-this distribution, and also F<eg/drum-fills-advanced> in the
-L<Music::Duration::Partition> distribution
+The F<eg/*> programs in this distribution. Also
+F<eg/drum-fills-advanced> in the L<Music::Duration::Partition>
+distribution.
+
+L<Algorithm::Combinatorics>
+
+L<MIDI::Util>
 
 L<Math::Bezier>
 
